﻿#pragma strict

import System.IO;

class TextureDump extends MonoBehaviour
{
	var renderFront : RenderTexture;
	var renderBack : RenderTexture;
	var renderLeft : RenderTexture;
	var renderRight : RenderTexture;
	var renderTop : RenderTexture;
	var renderDown : RenderTexture;
	
	private var captureCount : int = 0;
	
	function Update()
	{
		//If space is pressed capture
		if(Input.GetKeyDown(KeyCode.Tab))
			Capture();
	}
	
	//Sets file name for writing and calls capture function for each render texture set
	function Capture()
	{
		var path : String = Application.dataPath + "/../" + "FisheyeTextures/";
		
		Directory.CreateDirectory(path);
		
		if(renderFront)
			CaptureTexture(renderFront, path+"f"+captureCount);
		
		if(renderBack)
			CaptureTexture(renderBack, path+"b"+captureCount);
		
		if(renderLeft)
			CaptureTexture(renderLeft, path+"l"+captureCount);
		
		if(renderRight)
			CaptureTexture(renderRight, path+"r"+captureCount);
		
		if(renderTop)
			CaptureTexture(renderTop, path+"t"+captureCount);
		
		if(renderDown)
			CaptureTexture(renderDown, path+"d"+captureCount);
		
		captureCount++;
	}
	
	//Saves a png of the render texture at the filepath
	function CaptureTexture(targetRT : RenderTexture, filePath : String)
	{
		var currentRT : RenderTexture = RenderTexture.active;
		RenderTexture.active = targetRT;
		
		var outputTexture = new Texture2D(targetRT.width, targetRT.height);
		outputTexture.ReadPixels(new Rect(0, 0, outputTexture.width, outputTexture.height), 0, 0);
		outputTexture.Apply();
		
		var bytes = outputTexture.EncodeToPNG();
		Destroy(outputTexture);
		
		File.WriteAllBytes(filePath+".png", bytes);
		
		RenderTexture.active = currentRT;
	}
}